# Generated by roxygen2: do not edit by hand

export(build_all_tables)
export(build_forest_plot)
export(build_radar_plot)
export(build_steps_plots)
export(build_steps_tables)
export(build_table)
export(clean_steps_data)
export(compute_alcohol_indicators)
export(compute_all_indicators)
export(compute_all_tables)
export(compute_anthropometry_indicators)
export(compute_biochemical_indicators)
export(compute_bp_indicators)
export(compute_diet_pa_indicators)
export(compute_table)
export(compute_tobacco_indicators)
export(detect_col)
export(detect_steps_columns)
export(generate_test_data)
export(get_registry_by_section)
export(get_registry_by_step)
export(import_steps_data)
export(list_registry_sections)
export(plot_completeness)
export(plot_digit_preference)
export(plot_weights)
export(read_column_mapping)
export(recode_yn)
export(render_country_report)
export(render_data_book)
export(render_fact_sheet)
export(run_app)
export(run_steps_pipeline)
export(save_steps_plots)
export(setup_survey_design)
export(steps_colors)
export(steps_config)
export(steps_data_quality)
export(steps_table_registry)
export(svymn)
export(svyprop)
export(theme_steps)
importFrom(ggplot2,"%+replace%")
importFrom(stats,as.formula)
importFrom(stats,confint)
importFrom(stats,rbinom)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(utils,head)
