% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/visualizations.R
\name{make_age_chart}
\alias{make_age_chart}
\title{Create age-stratified trend chart}
\usage{
make_age_chart(by_age_df, title, steps_colors, theme_steps)
}
\arguments{
\item{by_age_df}{Data frame with \code{age_group}, \code{estimate}, \code{lower}, \code{upper} columns.}

\item{title}{Plot title.}

\item{steps_colors}{Colour list from \code{\link[=steps_colors]{steps_colors()}}.}

\item{theme_steps}{Theme from \code{\link[=theme_steps]{theme_steps()}}.}
}
\value{
A ggplot2 object or NULL if input is NULL.
}
\description{
Create age-stratified trend chart
}
\keyword{internal}
