% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mod_quality.R
\name{mod_quality_server}
\alias{mod_quality_server}
\title{Data Quality Module — Server}
\usage{
mod_quality_server(id, upload_out, clean_out)
}
\arguments{
\item{id}{Module namespace id.}

\item{upload_out}{Reactive list returned by \code{\link[=mod_upload_server]{mod_upload_server()}}, containing
\code{raw} (data frame), \code{cols} (column mapping), and \code{config} (survey config).}

\item{clean_out}{Reactive returning the cleaned data frame from
\code{\link[=mod_clean_server]{mod_clean_server()}}.}
}
\value{
A reactive returning the \code{steps_quality} object (or NULL).
}
\description{
Data Quality Module — Server
}
\keyword{internal}
