% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/indicators_bp.R
\name{compute_bp_indicators}
\alias{compute_bp_indicators}
\title{Compute Blood Pressure Indicators}
\usage{
compute_bp_indicators(design)
}
\arguments{
\item{design}{A survey design object from \code{\link[=setup_survey_design]{setup_survey_design()}}.}
}
\value{
A named list of survey estimates. Each element contains estimates
(as tibble with columns: estimate, lower, upper, etc.) for:
\itemize{
\item \code{raised_bp_total}: raised blood pressure, overall
\item \code{raised_bp_by_sex}: raised blood pressure, by sex
\item \code{raised_bp_by_age}: raised blood pressure, by age group
\item \code{mean_sbp_mean_total}: mean systolic BP, overall
\item \code{mean_sbp_mean_by_sex}: mean systolic BP, by sex
\item \code{mean_sbp_mean_by_age}: mean systolic BP, by age group
\item \code{mean_dbp_mean_total}: mean diastolic BP, overall
\item \code{mean_dbp_mean_by_sex}: mean diastolic BP, by sex
\item \code{mean_dbp_mean_by_age}: mean diastolic BP, by age group
(if the corresponding variables exist in design)
}
}
\description{
Calculates prevalence of raised blood pressure and mean systolic and
diastolic blood pressure from a survey design object.
}
\examples{
\donttest{
  test_data <- generate_test_data(n = 500, seed = 42)
  cols <- detect_steps_columns(test_data)
  clean <- clean_steps_data(test_data, cols)
  design <- setup_survey_design(clean)
  bp_results <- compute_bp_indicators(design)
}
}
\seealso{
\code{\link[=compute_all_indicators]{compute_all_indicators()}}
}
