% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/indicators_diet_pa.R
\name{compute_diet_pa_indicators}
\alias{compute_diet_pa_indicators}
\title{Compute Diet and Physical Activity Indicators}
\usage{
compute_diet_pa_indicators(design)
}
\arguments{
\item{design}{A survey design object from \code{\link[=setup_survey_design]{setup_survey_design()}}.}
}
\value{
A named list of survey estimates. Each element contains estimates
(as tibble with columns: estimate, lower, upper, etc.) for:
\itemize{
\item \code{insufficient_pa_total}: insufficient physical activity, overall
\item \code{insufficient_pa_by_sex}: insufficient physical activity, by sex
\item \code{insufficient_pa_by_age}: insufficient physical activity, by age group
\item \code{low_fruit_veg_total}: low fruit & vegetable intake, overall
\item \code{low_fruit_veg_by_sex}: low fruit & vegetable intake, by sex
\item \code{low_fruit_veg_by_age}: low fruit & vegetable intake, by age group
\item \code{met_mean_total}: mean MET (if available)
\item \code{met_mean_by_sex}: mean MET by sex (if available)
(if the corresponding variables exist in design)
}
}
\description{
Calculates prevalence of insufficient physical activity and low fruit &
vegetable intake, plus mean metabolic equivalent (MET) values, from a
survey design object.
}
\examples{
\donttest{
  test_data <- generate_test_data(n = 500, seed = 42)
  cols <- detect_steps_columns(test_data)
  clean <- clean_steps_data(test_data, cols)
  design <- setup_survey_design(clean)
  diet_pa_results <- compute_diet_pa_indicators(design)
}
}
\seealso{
\code{\link[=compute_all_indicators]{compute_all_indicators()}}
}
