% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mod_visualise.R
\name{mod_visualise_ui}
\alias{mod_visualise_ui}
\title{Visualise Module — UI}
\usage{
mod_visualise_ui(id)
}
\arguments{
\item{id}{Module namespace id.}
}
\value{
A Shiny UI definition.
}
\description{
Creates the user interface for the visualisation module, including a "Generate plots"
action button and tabbed layout for displaying STEPS survey visualizations.
}
\keyword{internal}
