% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/table_builder.R
\name{.fmt_ci}
\alias{.fmt_ci}
\title{Format a single estimate with CI}
\usage{
.fmt_ci(est, lower, upper, digits = 1, is_pct = TRUE)
}
\arguments{
\item{est}{Numeric estimate.}

\item{lower}{Lower CI bound.}

\item{upper}{Upper CI bound.}

\item{digits}{Decimal places.}

\item{is_pct}{If TRUE, values are already in percent; add "\%" suffix.}
}
\value{
Formatted string.
}
\description{
Format a single estimate with CI
}
\keyword{internal}
