% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mod_upload.R
\name{mod_upload_ui}
\alias{mod_upload_ui}
\title{Upload Module — UI}
\usage{
mod_upload_ui(id)
}
\arguments{
\item{id}{Module namespace id.}
}
\description{
Upload Module — UI
}
\keyword{internal}
