% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/compute_engine.R
\name{.vars_available}
\alias{.vars_available}
\title{Check if variable(s) exist in data}
\usage{
.vars_available(vars, data)
}
\description{
Check if variable(s) exist in data
}
\keyword{internal}
