% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/compute_engine.R
\name{.compute_mean}
\alias{.compute_mean}
\title{Compute a mean table (type = "mean")}
\usage{
.compute_mean(entry, design, data)
}
\description{
For single variable: total, by_sex, by_age.
For multiple variables: a named list, each with total, by_sex, by_age.
}
\keyword{internal}
