% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/table_builder.R
\name{.build_proportion_table}
\alias{.build_proportion_table}
\title{Build a proportion table}
\usage{
.build_proportion_table(result)
}
\description{
Build a proportion table
}
\keyword{internal}
