% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/compute_engine.R
\name{.compute_cascade}
\alias{.compute_cascade}
\title{Compute a cascade table (type = "cascade")}
\usage{
.compute_cascade(entry, design, data)
}
\description{
A cascade is a series of proportions, each possibly with a different
denominator (nested). Returns named list, each with total, by_sex, by_age.
}
\keyword{internal}
