% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/steps_registry.R
\name{get_registry_by_section}
\alias{get_registry_by_section}
\title{Get table registry entries by section}
\usage{
get_registry_by_section(section = NULL)
}
\arguments{
\item{section}{Section name (e.g., "Tobacco Use", "Blood Pressure").
If NULL, returns all entries.}
}
\value{
A filtered list of registry entries.
}
\description{
Get table registry entries by section
}
