% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/table_builder.R
\name{build_all_tables}
\alias{build_all_tables}
\title{Build all tables from computed results}
\usage{
build_all_tables(results)
}
\arguments{
\item{results}{A named list of results from \code{\link[=compute_all_tables]{compute_all_tables()}}.}
}
\value{
A named list of flextable objects. NULL entries excluded.
}
\description{
Build all tables from computed results
}
