% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/theme.R
\name{theme_steps}
\alias{theme_steps}
\title{WHO STEPS ggplot2 theme}
\usage{
theme_steps(base_size = 11)
}
\arguments{
\item{base_size}{Base font size (default 11).}
}
\value{
A \link[ggplot2:theme]{ggplot2::theme} object.
}
\description{
A clean, minimal ggplot2 theme styled with WHO STEPS colours.
}
\examples{
library(ggplot2)
ggplot(mtcars, aes(wt, mpg)) + geom_point() + theme_steps()
}
