% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/indicators_biochemical.R
\name{compute_biochemical_indicators}
\alias{compute_biochemical_indicators}
\title{Compute Biochemical Indicators}
\usage{
compute_biochemical_indicators(design)
}
\arguments{
\item{design}{A survey design object from \code{\link[=setup_survey_design]{setup_survey_design()}}.}
}
\value{
A named list of survey estimates. Each element contains estimates
(as tibble with columns: estimate, lower, upper, etc.) for:
\itemize{
\item \code{raised_glucose_total}: raised fasting glucose, overall
\item \code{raised_glucose_by_sex}: raised fasting glucose, by sex
\item \code{raised_glucose_by_age}: raised fasting glucose, by age group
\item \code{diabetes_total}: diabetes, overall
\item \code{diabetes_by_sex}: diabetes, by sex
\item \code{diabetes_by_age}: diabetes, by age group
\item \code{impaired_glucose_total}: impaired fasting glucose, overall
\item \code{impaired_glucose_by_sex}: impaired fasting glucose, by sex
\item \code{impaired_glucose_by_age}: impaired fasting glucose, by age group
\item \code{raised_chol_total}: raised total cholesterol, overall
\item \code{raised_chol_by_sex}: raised total cholesterol, by sex
\item \code{raised_chol_by_age}: raised total cholesterol, by age group
\item \code{fasting_glucose_mean_total}: mean fasting glucose, overall
\item \code{fasting_glucose_mean_by_sex}: mean fasting glucose, by sex
\item \code{total_chol_mean_total}: mean total cholesterol, overall
\item \code{total_chol_mean_by_sex}: mean total cholesterol, by sex
(if the corresponding variables exist in design)
}
}
\description{
Calculates prevalence of raised glucose, diabetes, impaired glucose
tolerance, and raised cholesterol, plus mean fasting glucose and total
cholesterol from a survey design object.
}
\examples{
\donttest{
  test_data <- generate_test_data(n = 500, seed = 42)
  cols <- detect_steps_columns(test_data)
  clean <- clean_steps_data(test_data, cols)
  design <- setup_survey_design(clean)
  biochemical_results <- compute_biochemical_indicators(design)
}
}
\seealso{
\code{\link[=compute_all_indicators]{compute_all_indicators()}}
}
