% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/app_ui.R
\name{app_ui}
\alias{app_ui}
\title{Main Shiny UI}
\usage{
app_ui()
}
\value{
A Shiny UI definition.
}
\description{
Builds the top-level UI using bslib sidebar page.
}
\keyword{internal}
