% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/table_builder.R
\name{.style_steps_table}
\alias{.style_steps_table}
\title{Apply WHO STEPS styling to a flextable}
\usage{
.style_steps_table(ft, title, description = NULL)
}
\arguments{
\item{ft}{A flextable object.}

\item{title}{Table title.}

\item{description}{Optional description text.}
}
\value{
Styled flextable.
}
\description{
Apply WHO STEPS styling to a flextable
}
\keyword{internal}
