% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/compute_engine.R
\name{.compute_proportion}
\alias{.compute_proportion}
\title{Compute a proportion table (type = "proportion")}
\usage{
.compute_proportion(entry, design, data)
}
\description{
Produces total, by_sex, by_age data frames with estimate, lower, upper.
Values are in percentage (0-100).
}
\keyword{internal}
